:description: This package defines dataset file format and load/output methods
    for Review Graph Mining Project.

.. _top:

Dataset I/O Library
======================
.. raw:: html

   <div class="addthis_inline_share_toolbox"></div>

This package defines dataset file format and load/output methods for
`Review Graph Mining Project </>`_.
See :doc:`modules/dataset_io` for detailed information.


Installation
--------------
Use `pip` to install this package.

.. code-block:: bash

   pip install --upgrade rgmining-dataset-io


API Reference
---------------
.. toctree::
  :glob:
  :maxdepth: 2

  modules/*


License
---------
This software is released under The GNU General Public License Version 3,
see COPYING for more detail.
